#ifndef _AUDIO_IO_H
#define _AUDIO_IO_H

/*
 * audio_io.h
 * $Id: audio_io.h,v 1.2 2003/05/18 11:03:21 richi Exp $
 *
 * Copyright (C) 2001 Richard Guenther, Alexander Ehlert, Daniel Kobras
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "glplugin.h"
#include "filter.h"


filter_t *aio_generic_register_input(plugin_t *pl, char *name,
				     int (*f)(filter_t *),
				     const char *defaultdevice);


filter_t *aio_generic_register_output(plugin_t *pl, char *name,
				     int (*f)(filter_t *),
				     const char *defaultdevice);


#endif
